@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0404';
+our $VERSION = '0.0405';
 
 use strictures 2;
 use AI::Prolog ();
@@ -271,7 +271,7 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0404
+version 0.0405
 
 =head1 SYNOPSIS
 
@@ -302,6 +302,16 @@ version 0.0404
   #  ... ]
   # Inspecting all the results, we see that the answers are D Dorian, D Ionian, and D Mixolydian.
 
+  # What chords do C major and F♯ (G♭) major have in common?
+  $m = Music::ModalFunction->new(
+    mode_note    => 'c',
+    mode         => 'ionian',
+    key_note     => 'gb',
+    key          => 'ionian',
+    hash_results => 1,
+  );
+  $results = $m->pivot_chord_keys; # There are no chords in common!
+
 =head1 DESCRIPTION
 
 C<Music::ModalFunction> allows querying of a musical database of
@@ -383,6 +393,9 @@ Default: C<0>
 
 Create a new C<Music::ModalFunction> object.
 
+If defined, argument values will be bound to a variable. Otherwise an
+unbound variable is used for the queries detailed below.
+
 =head2 chord_key
 
   $results = $m->chord_key;
@@ -399,9 +412,6 @@ in the key is the B<key_function> and basically indicates the relative
 scale position. The B<key_roman> argument serves as an indicator of
 both the chord quality and the position in the scale.
 
-If defined, argument values will be bound to a variable. Otherwise an
-unbound variable is used.
-
 =head2 pivot_chord_keys
 
   $results = $m->pivot_chord_keys;
@@ -422,9 +432,6 @@ transformation (often a pivot). The function of the chord in the
 "destination" is B<key_function>. As with mode_roman, B<key_roman> is
 the resulting chord quality and scale position.
 
-If defined, argument values will be bound to a variable. Otherwise an
-unbound variable is used.
-
 =head2 roman_key
 
   $results = $m->roman_key;
@@ -436,9 +443,6 @@ Constructor arguments:
 
   mode, mode_roman, key, key_roman
 
-If defined, argument values will be bound to a variable. Otherwise an
-unbound variable is used.
-
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/*> files in this distribution
